OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "הפעולה שצוינה שגויה",
    "The given regular expression is invalid" : "הביטוי הרגולרי שצוין שגוי",
    "The given file size is invalid" : "גודל הקובץ שצוין שגוי",
    "The given tag id is invalid" : "התגית שצוינה שגויה",
    "The given IP range is invalid" : "טווח כתובות ה־IP שצוין שגוי",
    "The given IP range is not valid for IPv4" : "טווח כתובות ה־IP שצוין אינו תקף ל־IPv4",
    "The given IP range is not valid for IPv6" : "טווח כתובות ה־IP שצוין אינו תקף ל־IPv6",
    "The given time span is invalid" : "טווח הזמן שצוין שגוי",
    "The given start time is invalid" : "מועד ההתחלה שצוין שגוי",
    "The given end time is invalid" : "מועד הסיום שצוין שגוי",
    "The given group does not exist" : "הקבוצה שצוינה אינה קיימת",
    "File" : "קובץ",
    "File created" : "נוצר קובץ",
    "File updated" : "עודכן קובץ",
    "File renamed" : "שונה שם קובץ",
    "File deleted" : "מחק קובץ",
    "File accessed" : "הייתה גישה לקובץ",
    "File copied" : "הועתק קובץ",
    "Tag assigned" : "הוקצתה תגית",
    "Someone" : "מישהו",
    "Operation #%s does not exist" : "פעולה מס׳ %s לא קיימת",
    "Entity %s does not exist" : "היישות %s לא קיימת",
    "Entity %s is invalid" : "היישות %s שגויה",
    "No events are chosen." : "לא נבחרו אירועים.",
    "Entity %s has no event %s" : "ליישות %s אין אירוע %s",
    "Operation %s does not exist" : "הפעולה %s לא קיימת",
    "Operation %s is invalid" : "הפעולה %s שגויה",
    "At least one check needs to be provided" : "יש לספק לפחות בדיקה אחת",
    "Invalid check provided" : "סופקה בדיקה שגויה",
    "Check %s does not exist" : "הבדיקה %s לא קיימת",
    "Check %s is invalid" : "הבדיקה %s שגויה",
    "Check %s is not allowed with this entity" : "הבדיקה %s אסורה ביישות הזאת",
    "Check #%s does not exist" : "בדיקה מס׳ %s לא קיימת",
    "Check %s is invalid or does not exist" : "הבדיקה %s שגויה או שאינה קיימת",
    "Flow" : "רצף",
    "Nextcloud workflow engine" : "מנגנון רצף הפעילות של Nextcloud",
    "Select a filter" : "נא לבחור מסנן",
    "Select a comparator" : "נא לבחור משווה",
    "Select a file type" : "נא לבחור סוג קובץ",
    "e.g. httpd/unix-directory" : "למשל: httpd/unix-directory",
    "Folder" : "תיקייה",
    "Images" : "תמונות",
    "Office documents" : "מסמכי אופיס (Office)",
    "PDF documents" : "מסמכי RDF",
    "Custom mimetype" : "נא לבחור טיפוס MIME",
    "Please enter a valid time span" : "נא למלא טווח זמן תקין",
    "Select a request URL" : "נא לבחור את כתובת הבקשה",
    "Files WebDAV" : "WebDAV קבצים",
    "Custom URL" : "כתובת מותאמת אישית",
    "Select a user agent" : "נא לבחור סוכן משתמש",
    "Android client" : "לקוח Android",
    "iOS client" : "לקוח iOS",
    "Desktop client" : "לקוח שולחן עבודה",
    "Thunderbird & Outlook addons" : "תוספות ל־Thunderbird ול־Outlook",
    "Custom user agent" : "סוכן משתמש מותאם אישית",
    "At least one event must be selected" : "יש לבחור באירוע אחד לפחות",
    "Add new flow" : "הוספת רצף חדש",
    "When" : "מתי",
    "and" : "וגם",
    "Cancel" : "ביטול",
    "Delete" : "מחיקה",
    "The configuration is invalid" : "ההגדרות שגויות",
    "Active" : "פעיל",
    "Save" : "שמירה",
    "Available flows" : "רצפים זמינים",
    "For details on how to write your own flow, check out the development documentation." : "לפרטים על כתיבת רצף משלך, יש לפנות אל התיעוד למפתחים.",
    "More flows" : "רצפים נוספים",
    "Show less" : "להציג פחות",
    "Show more" : "להציג יותר",
    "Configured flows" : "רצפים מוגדרים",
    "Your flows" : "הרצפים שלך",
    "matches" : "תואם",
    "does not match" : "אינו תואם",
    "is" : "הוא",
    "is not" : "אינו",
    "File name" : "שם קובץ",
    "File MIME type" : "סוג ה־MIME של הקובץ",
    "File size (upload)" : "גודל קובץ (העלאה)",
    "less" : "פחות",
    "less or equals" : "פחות או שווה",
    "greater or equals" : "גדול או שווה",
    "greater" : "גדול",
    "Request remote address" : "בקשת כתובת מרוחקת",
    "matches IPv4" : "התאמת IPv4",
    "does not match IPv4" : "ללא התאמת IPv4",
    "matches IPv6" : "התאמת IPv6",
    "does not match IPv6" : "ללא התאמת IPv6",
    "File system tag" : "תגית מערכת קבצים",
    "is tagged with" : "עם התגית",
    "is not tagged with" : "ללא התגית",
    "Request URL" : "כתובת בקשה",
    "Request time" : "זמן בקשה",
    "between" : "בין",
    "not between" : "לא בין",
    "Request user agent" : "סוכן משתמש הבקשה",
    "is member of" : "חבר בקבוצה",
    "is not member of" : "לא חבר בקבוצה",
    "User group membership" : "חברות בקבוצת משתמשים"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
